<?php
namespace Aws\CodeGuruSecurity\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon CodeGuru Security** service.
 */
class CodeGuruSecurityException extends AwsException {}
